@@ -21,6 +21,12 @@ from bamboo_engine.config import Settings
 from bamboo_engine.context import Context
 from bamboo_engine.eri.models.interrupt import ScheduleInterruptPoint
 from bamboo_engine.interrupt import ExecuteKeyPoint, ScheduleKeyPoint
+from bamboo_engine.metrics import (
+    ENGINE_SCHEDULE_FAILED_COUNT,
+    ENGINE_EXECUTE_FAILED_COUNT,
+    ENGINE_EXECUTE_EXCEPTION_COUNT,
+    ENGINE_SCHEDULE_EXCEPTION_COUNT,
+)
 from bamboo_engine.template import Template
 from bamboo_engine.eri import (
     ProcessInfo,
@@ -208,7 +214,8 @@ class ServiceActivityHandler(NodeHandler):
             root_pipeline_id,
             root_pipeline_data,
         )
-
+        # build_node_type: sleep_timer_legacy
+        node_type = "{}_{}".format(self.node.code, self.node.version)
         # try recover from executed recover point
         execute_success = False
         if recover_point and recover_point.handler_data.service_executed:
@@ -223,11 +230,15 @@ class ServiceActivityHandler(NodeHandler):
             try:
                 execute_success = service.execute(data=service_data, root_pipeline_data=root_pipeline_data)
             except Exception:
+                ENGINE_EXECUTE_EXCEPTION_COUNT.labels(type=node_type, hostname=self._hostname).inc()
                 ex_data = traceback.format_exc()
                 service_data.outputs.ex_data = ex_data
                 logger.warning("root_pipeline[%s]service execute fail: %s", process_info.root_pipeline_id, ex_data)
             logger.debug("root_pipeline[%s] service data after execute: %s", root_pipeline_id, service_data)
 
+        if not execute_success:
+            ENGINE_EXECUTE_FAILED_COUNT.labels(type=node_type, hostname=self._hostname).inc()
+
         with metrics.observe(
             metrics.ENGINE_NODE_EXECUTE_POST_PROCESS_DURATION, type=self.node.type.value, hostname=self._hostname
         ):
@@ -419,6 +430,8 @@ class ServiceActivityHandler(NodeHandler):
                 inner_loop=inner_loop,
             )
 
+        # build_node_type: sleep_timer_legacy
+        node_type = "{}_{}".format(self.node.code, self.node.version)
         # schedule
         schedule_success = False
         is_schedule_done = False
@@ -441,10 +454,14 @@ class ServiceActivityHandler(NodeHandler):
                     callback_data=callback_data,
                 )
             except Exception:
+                ENGINE_SCHEDULE_EXCEPTION_COUNT.labels(type=node_type, hostname=self._hostname).inc()
                 service_data.outputs.ex_data = traceback.format_exc()
             else:
                 is_schedule_done = service.is_schedule_done()
 
+        if not schedule_success:
+            ENGINE_SCHEDULE_FAILED_COUNT.labels(type=node_type, hostname=self._hostname).inc()
+
         with metrics.observe(
             metrics.ENGINE_NODE_SCHEDULE_POST_PROCESS_DURATION, type=self.node.type.value, hostname=self._hostname
         ):
